@@ -31,20 +31,15 @@ build_time_vars = {'ABIFLAGS': '',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=x86-64 '
            '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -fcf-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-           '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic -O3 '
-           '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wformat -Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-           '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -fcf-protection -flto=auto '
+           '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-           '-flto=auto',
+           '-fcf-protection -flto=auto -march=x86-64 -mtune=generic -O3 -pipe '
+           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection '
+           '-fcf-protection -flto=auto',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -54,11 +49,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection '
-                     '-fcf-protection -g '
-                     '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                     '-flto=auto -ffat-lto-objects',
+                     '-fcf-protection -flto=auto -ffat-lto-objects',
  'CONFIGURE_CFLAGS_NODIST': '-fno-semantic-interposition -flto '
                             '-fuse-linker-plugin -ffat-lto-objects '
                             '-flto-partition=none -g -std=c11 '
@@ -79,19 +72,18 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=x86-64 "
                 '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-                '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection '
-                '-fcf-protection -g '
-                '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                "-flto=auto -ffat-lto-objects' 'LDFLAGS=-Wl,-O1 "
-                '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
-                "-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto'",
+                "-fcf-protection -flto=auto -ffat-lto-objects' "
+                "'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed "
+                '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+                "-flto=auto'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.12.3/coverage.info',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.12.4/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.12.3/lcov-report',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.12.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -203,7 +195,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_TYPEAHEAD': 1,
  'HAVE_CURSES_USE_ENV': 1,
  'HAVE_CURSES_WCHGAT': 1,
- 'HAVE_DB_H': 1,
+ 'HAVE_DB_H': 0,
  'HAVE_DECL_RTLD_DEEPBIND': 1,
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
@@ -347,7 +339,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LIBB2': 0,
- 'HAVE_LIBDB': 1,
+ 'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
  'HAVE_LIBIEEE': 0,
@@ -669,23 +661,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=x86-64 '
                     '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                    '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic '
+                    '-fcf-protection -flto=auto -ffat-lto-objects '
+                    '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-fcf-protection -flto=auto -march=x86-64 -mtune=generic '
                     '-O3 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                    '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe '
-                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                    '-Wformat -Werror=format-security         '
-                    '-fstack-clash-protection -fcf-protection -g '
-                    '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                    '-flto=auto -fno-semantic-interposition -flto '
-                    '-fuse-linker-plugin -ffat-lto-objects '
+                    '-fcf-protection -flto=auto -fno-semantic-interposition '
+                    '-flto -fuse-linker-plugin -ffat-lto-objects '
                     '-flto-partition=none -g -std=c11 '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -695,26 +682,21 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=x86-64 '
                    '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                   '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic '
+                   '-fcf-protection -flto=auto -ffat-lto-objects -march=x86-64 '
+                   '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-fcf-protection -flto=auto -march=x86-64 -mtune=generic '
                    '-O3 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                   '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                   '-flto=auto -fno-semantic-interposition -flto '
-                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
-                   '-g -std=c11 -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-fPIC -fPIC',
+                   '-fcf-protection -flto=auto -fno-semantic-interposition '
+                   '-flto -fuse-linker-plugin -ffat-lto-objects '
+                   '-flto-partition=none -g -std=c11 '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -724,23 +706,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=x86-64 '
                     '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                    '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic '
+                    '-fcf-protection -flto=auto -ffat-lto-objects '
+                    '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-fcf-protection -flto=auto -march=x86-64 -mtune=generic '
                     '-O3 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-fcf-protection -g '
-                    '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                    '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe '
-                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                    '-Wformat -Werror=format-security         '
-                    '-fstack-clash-protection -fcf-protection -g '
-                    '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                    '-flto=auto -fno-semantic-interposition -flto '
-                    '-fuse-linker-plugin -ffat-lto-objects '
+                    '-fcf-protection -flto=auto -fno-semantic-interposition '
+                    '-flto -fuse-linker-plugin -ffat-lto-objects '
                     '-flto-partition=none -g -std=c11 '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -1109,22 +1086,19 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
                              '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+                             '-fstack-clash-protection -fcf-protection '
                              '-flto=auto -ffat-lto-objects -march=x86-64 '
                              '-mtune=generic -O3 -pipe -fno-plt '
-                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+                             '-fstack-clash-protection -fcf-protection '
                              '-flto=auto -march=x86-64 -mtune=generic -O3 '
                              '-pipe -fno-plt -fexceptions         '
-                             '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                             '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                              '-Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+                             '-fstack-clash-protection -fcf-protection '
                              '-flto=auto -fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g -std=c11 '
@@ -1133,21 +1107,16 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=x86-64 '
               '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-              '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic -O3 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+              '-fcf-protection -flto=auto -ffat-lto-objects -march=x86-64 '
+              '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-fcf-protection -flto=auto -march=x86-64 -mtune=generic -O3 '
+              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
               '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -fcf-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-              '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-              '-flto=auto',
+              '-fstack-clash-protection -fcf-protection -flto=auto',
  'PY_CFLAGS_NODIST': '-fno-semantic-interposition -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -flto-partition=none -g -std=c11 '
                      '-Werror=implicit-function-declaration '
@@ -1155,26 +1124,21 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=x86-64 '
                    '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                   '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic '
+                   '-fcf-protection -flto=auto -ffat-lto-objects -march=x86-64 '
+                   '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-fcf-protection -flto=auto -march=x86-64 -mtune=generic '
                    '-O3 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                   '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                   '-flto=auto -fno-semantic-interposition -flto '
-                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
-                   '-g -std=c11 -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-fPIC -DPy_BUILD_CORE',
+                   '-fcf-protection -flto=auto -fno-semantic-interposition '
+                   '-flto -fuse-linker-plugin -ffat-lto-objects '
+                   '-flto-partition=none -g -std=c11 '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
                     '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
                     '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
@@ -1202,24 +1166,20 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
                         '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-flto=auto -ffat-lto-objects -march=x86-64 '
-                        '-mtune=generic -O3 -pipe -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-fstack-clash-protection -fcf-protection -flto=auto '
+                        '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 '
+                        '-pipe -fno-plt -fexceptions         '
+                        '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe '
-                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                        '-Wformat -Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-flto=auto -fno-semantic-interposition -flto '
-                        '-fuse-linker-plugin -ffat-lto-objects '
-                        '-flto-partition=none -g -std=c11 '
+                        '-fstack-clash-protection -fcf-protection -flto=auto '
+                        '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -fcf-protection -flto=auto '
+                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                        '-ffat-lto-objects -flto-partition=none -g -std=c11 '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -1234,7 +1194,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1360,9 +1320,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1379,7 +1339,7 @@ build_time_vars = {'ABIFLAGS': '',
  'WASM_ASSETS_DIR': './usr',
  'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '',
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -1392,8 +1352,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.12.3',
- 'abs_srcdir': '/build/python/src/Python-3.12.3',
+ 'abs_builddir': '/build/python/src/Python-3.12.4',
+ 'abs_srcdir': '/build/python/src/Python-3.12.4',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
